## *deeptools in wondows*

based on bamnostic and pybigtools
-->
## :writing_hand: xpf

[![pipy](https://img.shields.io/badge/PIPY-0.1.1-green)](https://pypi.org/project/my-deeptools-win/)
[![github](https://img.shields.io/badge/GITHUB-0.1.1-green)](https://github.com/yang)
[![windows](https://img.shields.io/badge/WINDOWS-11-blue)](https://www.microsoft.com/zh-cn/windows/windows-11)
[![bamnostic](https://img.shields.io/badge/BAMNOSTIC-1.0.0-blue)](https://pypi.org/project/bamnostic/)